package org.greenstone.gatherer.gui;
/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.util.Utility;
/**
 * @author John Thompson, Greenstone Digital Library, University of Waikato
 * @version 2.1
 */
public class GPrompt
	 extends JDialog
	 implements ActionListener {

	 private JButton close;

	 private JPanel content_pane;

	 // Static
	 static private Dimension SIZE      = new Dimension(420, 140);
	 static private Dimension TEXT_SIZE = new Dimension(380, 60);

	 public GPrompt(Dialog owner, String title, String message, String left_image, String right_image) {
		  super(owner);
		  build_dialog(title, message, left_image, right_image);
	 }

	 public GPrompt(Frame owner, String title, String message, String left_image, String right_image) {
		  super(owner);
		  build_dialog(title, message, left_image, right_image);
	 }

	 public void actionPerformed(ActionEvent event) {
		  if(event.getSource() == close) {
				// Check the show setting.
				this.dispose();
		  }
	 }
	 
	 public void destroy() {
		  close = null;
		  content_pane = null;
	 }

	 public void display() {		  
		  this.show();
	 }

	 /** This private method creates and lays out the components within this
	  * dialog box based on its arguments.
	  * @param message A String content to be displayed.
	  * @param left_name The name of the left image as a String.
	  * @param right_name The name of the right image as a String.
	  */
	 private void build_dialog(String title, String message, String left_name, String right_name) {
		  this.setModal(true);
		  this.setSize(SIZE);
		  this.setTitle(title);

		  // Create components
		  content_pane = (JPanel) this.getContentPane();
		  content_pane.setBackground(Gatherer.config.getColor("coloring.collection_heading_background", false));

		  JLabel image_left_label = null;
		  if(left_name != null) {
				ImageIcon image_left = Utility.getImage(left_name);
				image_left_label = new JLabel(image_left);
				image_left_label.setOpaque(false);
		  }

		  JPanel text_pane = new JPanel();
		  text_pane.setOpaque(false);

		  JTextArea text = new JTextArea(message);
		  text.setBackground(Gatherer.config.getColor("coloring.collection_tree_background", false));
		  text.setColumns(40);
		  text.setEditable(false);
		  text.setLineWrap(true);
		  text.setRows(3);
		  text.setWrapStyleWord(true);

		  JLabel image_right_label = null;
		  if(right_name != null) {
				ImageIcon image_right = Utility.getImage(right_name);
				image_right_label = new JLabel(image_right);
				image_right_label.setOpaque(false);
		  }

		  close = new JButton(get("General.Close"));
		  close.addActionListener(this);
		  close.setBackground(Gatherer.config.getColor("coloring.button_background", false));

		  // Layout components
		  text_pane.setBorder(BorderFactory.createEmptyBorder(0,5,5,5));
		  text_pane.setLayout(new BorderLayout());
		  text_pane.add(text, BorderLayout.CENTER);

		  content_pane.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
		  content_pane.setLayout(new BorderLayout());
		  if(image_left_label != null) {
				content_pane.add(image_left_label, BorderLayout.WEST);
		  }
		  content_pane.add(text_pane, BorderLayout.CENTER);
		  content_pane.add(close, BorderLayout.SOUTH);
		  if(image_right_label != null) {
				content_pane.add(image_right_label, BorderLayout.EAST);
		  }
		  // Locate dialog on screen.
		  Dimension screen_size = Gatherer.config.screen_size;
		  this.setLocation((screen_size.width - SIZE.width) / 2, (screen_size.height - SIZE.height) / 2);
	 }

	 private String get(String key) {
		  return get(key, null);
	 }

	 private String get(String key, String args[]) {
		  if(key.indexOf(".") == -1) {
				key = "GPrompt."+key;
		  }
		  return Gatherer.dictionary.get(key, args);
	 }
}
