package org.greenstone.gatherer.gui;
/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
import calpa.html.*;
import java.awt.*;
import java.awt.event.*;
import java.net.*;
import javax.swing.*;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.util.GURL;
import org.greenstone.gatherer.util.Utility;

public class PreviewPane 
	 extends JPanel {
	 
	 private CalHTMLPane view   = null;
	 private int back_count     = 0;
	 private int forward_count  = 0;
	 private JButton back       = null;
	 private JButton forward    = null;
	 private JButton home       = null;
	 private JButton reload = null;
	 private JLabel status      = null;
	 private String args[]      = null;
	 private String current_url = null;
	 private String page_showing = null;
	 private URL homepage       = null;

	 public PreviewPane() {
		  // Create components
		  back = new JButton(get("Back"), Utility.getImage("back.gif"));
		  back.addActionListener(new BackListener());
		  back.setEnabled(false);

		  home = new JButton(get("Home"), Utility.getImage("home.gif"));
		  home.addActionListener(new HomeListener());
		  home.setEnabled(false);

		  forward = new JButton(get("Forward"), Utility.getImage("forward.gif"));
		  forward.addActionListener(new ForwardListener());
		  forward.setEnabled(false);

		  reload = new JButton(get("Reload"), Utility.getImage("reload.gif"));
		  reload.addActionListener(new ReloadListener());
		  reload.setEnabled(false);

		  CalHTMLPreferences prefs = new CalHTMLPreferences();
		  Observer observer = new Observer();
		  view = new CalHTMLPane(prefs, observer, "Default");
		  //view.setSize(new Dimension(770, 440));

		  status = new JLabel(get("Ready"));
	 }
	 
	 public void collectionChanged(boolean ready) {
		  if(ready && Gatherer.c_man.built()) {
				String url = Gatherer.config.exec_path + "?a=p&p=about&c=" + Gatherer.c_man.getCollection().getName();
				Gatherer.println("Loading " + url);
				args = new String[1];
				args[0] = url;
				status.setText(get("Loading", args));
				args = null;
				view.showHTMLDocument((new GURL(url)).getURL());				
		  }
		  validate();
	 }

	 public void display() {
		  JPanel control_pane = new JPanel();
		  control_pane.setBorder(BorderFactory.createEmptyBorder(0,0,5,0));
		  control_pane.setLayout(new GridLayout(1,4));
		  control_pane.add(back);
		  control_pane.add(reload);
		  control_pane.add(home);
		  control_pane.add(forward);

		  JPanel a_panel = new JPanel(new BorderLayout());
		  a_panel.setSize(new Dimension(770, 440));
		  a_panel.add(view, BorderLayout.CENTER);

		  setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		  setLayout(new BorderLayout());
		  add(control_pane, BorderLayout.NORTH);
		  add(a_panel, BorderLayout.CENTER);
		  add(status, BorderLayout.SOUTH);
	 }

	 /** This method is called when the user selects the 'Preview' tab from the views bar. Can be used to display a particular page or perform some other relevant tests (ensure internet connection to specified server maybe?)
	  */
	 public void gainFocus() {
		  if(Gatherer.c_man.ready() && Gatherer.c_man.built()) {
				String url = Gatherer.config.exec_path + "?a=p&p=about&c=" + Gatherer.c_man.getCollection().getName();
				if(page_showing != null && page_showing.equals(url)) {
					 view.reloadDocument();
				}
				else {
					 Gatherer.println("Loading " + url);
					 args = new String[1];
					 args[0] = url;
					 status.setText(get("Loading", args));
					 args = null;
					 view.showHTMLDocument((new GURL(url)).getURL());
					 page_showing = url;
					 homepage = (new GURL(url)).getURL();
				}
		  }
		  validate();
	 }

	 /** Used to retrieve the phrase that matches the given key from the loaded dictionary. 
	  */
	 public String get(String key) {
		  return get(key, null);
	 }

	 public String get(String key, String args[]) {
		  if(key.indexOf(".") == -1) {
				key = "Browser." + key;
		  }
		  return Gatherer.dictionary.get(key, args);
	 }

	 public void validate() {
		  if(back_count > 0) {
				back.setEnabled(true);
		  }
		  else {
				back.setEnabled(false);
		  }
		  if(homepage != null) {
				home.setEnabled(true);
		  }
		  else {
				home.setEnabled(false);
		  }
		  if(forward_count > 0) {
				forward.setEnabled(true);
		  }
		  else {
				forward.setEnabled(false);
		  }
		  reload.setEnabled(true);
	 }

	 private class BackListener 
		  implements ActionListener {
		  public void actionPerformed(ActionEvent event) {
				view.goBack();
				back_count--;
				forward_count++;
				validate();
		  }
	 }

	 private class ForwardListener 
		  implements ActionListener {
		  public void actionPerformed(ActionEvent event) {
				view.goForward();
				back_count++;
				forward_count--;
				validate();
		  }
	 }

	 private class HomeListener
		  implements ActionListener {
		  public void actionPerformed(ActionEvent event) {
				if(homepage != null) {
					 view.showHTMLDocument(homepage);
					 back_count++;
					 validate();
				}
		  }
	 }

	 private class ReloadListener
		  implements ActionListener {
		  public void actionPerformed(ActionEvent event) {
				view.reloadDocument();
		  }
	 }

	 private class Observer
		  extends DefaultCalHTMLObserver {
		  public void linkActivatedUpdate(CalHTMLPane pane, URL url, String target_frame, String j_name) {
				if(!url.toString().equals(current_url)) {
					 back_count++;
					 forward_count = 0;
					 validate();
				}
		  }
		  public void linkFocusUpdate(CalHTMLPane pane, URL url) {
				///ystem.err.println("Link in focus " + url.toString());
				args = new String[1];
				args[0] = url.toString();
				status.setText(get("Follow"));
				args = null;
		  }
		  public void statusUpdate(CalHTMLPane pane, int state, URL url, int value, String message) {
				switch(state) {
				case 11:
					 args = new String[1];
					 args[0] = url.toString();
					 status.setText(get("Loading", args));
					 args = null;
					 break;
				case 14:
					 // Rendering complete.
					 status.setText(get("Ready"));
					 break;
				}
		  }
	 }
} 
